Learn R Programming

mcbette (version 1.15.3)

can_run_mcbette: Can 'mcbette' run?

Description

Can 'mcbette' run? Will return TRUE if:

  • (1) Running on Linux or MacOS

  • (2) BEAST2 is installed

  • (3) The BEAST2 NS package is installed

Usage

can_run_mcbette(beast2_folder = beastier::get_default_beast2_folder())

Value

TRUE if 'mcbette' can run.

Arguments

beast2_folder

the folder where the BEAST2 is installed. Note that this is not the folder where the BEAST2 executable is installed: the BEAST2 executable is in a subfolder. Use get_default_beast2_folder to get the default BEAST2 folder. Use get_default_beast2_bin_path to get the full path to the default BEAST2 executable. Use get_default_beast2_jar_path to get the full path to the default BEAST2 jar file.

Author

Richèl J.C. Bilderbeek

Examples

Run this code
can_run_mcbette()

beastier::remove_beaustier_folders()
beastier::check_empty_beaustier_folders()

Run the code above in your browser using DataLab