Learn R Programming

mcbette (version 1.15.3)

get_mcbette_state: Get the current state of mcbette

Description

Get the current state of mcbette

Usage

get_mcbette_state(beast2_folder = beastier::get_default_beast2_folder())

Value

a list with the following elements:

  • beast2_installed TRUE if BEAST2 is installed, FALSE otherwise

  • ns_installed TRUE if the BEAST2 NS package is installed FALSE if the BEAST2 or the BEAST2 NS package is not installed

Arguments

beast2_folder

the folder where the BEAST2 is installed. Note that this is not the folder where the BEAST2 executable is installed: the BEAST2 executable is in a subfolder. Use get_default_beast2_folder to get the default BEAST2 folder. Use get_default_beast2_bin_path to get the full path to the default BEAST2 executable. Use get_default_beast2_jar_path to get the full path to the default BEAST2 jar file.

Examples

Run this code
get_mcbette_state()

beastier::remove_beaustier_folders()
beastier::check_empty_beaustier_folders()

Run the code above in your browser using DataLab