nothing. It is intended that the output (not
the return value) is copy-pasted from screen.
Arguments
beast2_folder
the folder where the BEAST2 is installed.
Note that this is not the folder where the BEAST2 executable is installed:
the BEAST2 executable is in a subfolder.
Use get_default_beast2_folder
to get the default BEAST2 folder.
Use get_default_beast2_bin_path
to get the full path to the default BEAST2 executable.
Use get_default_beast2_jar_path
to get the full path to the default BEAST2 jar file.