Learn R Programming

mcbette (version 1.15.3)

set_mcbette_state: Set the mcbette state.

Description

Set the mcbette state to having BEAST2 installed with or without installing the BEAST2 NS package.

Usage

set_mcbette_state(
  mcbette_state,
  beast2_folder = beastier::get_default_beast2_folder(),
  verbose = FALSE
)

Value

Nothing.

Arguments

mcbette_state

the mcbette state, which is a list with the following elements:

  • beast2_installed TRUE if BEAST2 is installed, FALSE otherwise

  • ns_installed NA if BEAST2 is not installed. TRUE if the BEAST2 NS package is installed FALSE if the BEAST2 NS package is not installed

beast2_folder

the folder where the BEAST2 is installed. Note that this is not the folder where the BEAST2 executable is installed: the BEAST2 executable is in a subfolder. Use get_default_beast2_folder to get the default BEAST2 folder. Use get_default_beast2_bin_path to get the full path to the default BEAST2 executable. Use get_default_beast2_jar_path to get the full path to the default BEAST2 jar file.

verbose

if TRUE show debug output

See Also

  • Use get_mcbette_state to get the current mcbette state

  • Use check_mcbette_state to check the current mcbette state